
# This file was generated by 'versioneer.py' (0.20.dev0) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2021-12-16T01:41:50+0000",
 "dirty": false,
 "error": null,
 "full-revisionid": "107219b2e5d44e10d7589272767ad27c4ac6da41",
 "version": "0.15.4"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)



# emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
# ex: set sts=4 ts=4 sw=4 noet:
# ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
#
#   See COPYING file distributed along with the datalad package for the
#   copyright and license terms.
#
# ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
"""Auxiliary itertools"""

import itertools


def groupby_sorted(iter, key=None):
    """A little helper which first sorts iterable by the same key

    Since groupby expects sorted entries
    """
    yield from itertools.groupby(sorted(iter, key=key), key=key)
